@@ -1,3 +1,4 @@
+import numpy as np
 '''
 created by:Ashish Kumar
 created on:15/09/20
@@ -12,7 +13,7 @@ with in this range.
 
 If you find any problem in this package feel free to add issue here:- https://github.com/Ashish2000L/linear_programing
 '''
-class simplex:
+class TPsimplex:
     '''
     @:param
     No_of_constrains:int->  This is the number of equations in the problem
@@ -320,6 +321,17 @@ class simplex:
                     self.entering_indx = i
 
 
+    def __check_for_other_alternative(self,min:int):
+
+        ln=len(self.main_matrix[0])-1
+        for i,v in enumerate(self.basic_var):
+            b = self.main_matrix[i][ln]
+            x = self.main_matrix[i][self.entering_indx]
+            if v in self.artificial_var:
+                if (float(b/x)==min):
+                    self.leaving_indx=i
+
+
     def __find_leaving_indx(self, type='1_phase'):
 
         x=[]
@@ -341,6 +353,9 @@ class simplex:
                     if m<min:
                         min=m
                         self.leaving_indx=i+1
+
+            self.__check_for_other_alternative(min)
+
         elif type=='max':
 
             l = len(self.main_matrix[0])-1
@@ -376,9 +391,6 @@ class simplex:
                         self.leaving_indx = i + 1
 
 
-        #print(min,self.leaving_indx,self.entering_indx)
-
-
     def __set_enter_and_leave_val(self):
 
         temp_index=0
@@ -498,4 +510,22 @@ class simplex:
         while not self.__check_for_optimal_table(type=self.optimize_type):
             self.__find_entry_indx(type=self.optimize_type)
             self.__find_leaving_indx(type=self.optimize_type)
-            self.__set_enter_and_leave_val()
\ No newline at end of file
+            self.__set_enter_and_leave_val()
+
+
+    def Optimal_Solution(self)-> "numpy array":
+
+        ln=len(self.main_matrix[0])-1
+        if self.main_matrix[0][ln]>0:
+            print("\n\n\nSOLUTION:\n")
+            self.__print_matrix()
+            final_solution=[['F',self.main_matrix[0][ln]]]
+
+            cost_coeff_var=['X'+str(i+1) for i in range(self.number_of_variables)]
+            for i,v in enumerate(self.basic_var):
+                if v in cost_coeff_var:
+                    final_solution.append([v,self.main_matrix[i][ln]])
+
+            return np.asarray(final_solution)
+        else:
+            raise Exception("\n\nEither the equation have not fisible solution or an error occured.\n Please staceback to look for the issue, if you find this solution wrong you can create an issue here: \n https://github.com/Ashish2000L/linear_programing")
